<div class="{{counter_class}}">
    <button class="{{decrement_class}}" onclick="_addDelta('{{widget.attrs.id}}', -{{decrement_value}})">{{decrement_text}}</button>
    {% include "django/forms/widgets/input.html" %}
    <button class="{{increment_class}}" onclick="_addDelta('{{widget.attrs.id}}', {{increment_value}})">{{increment_text}}</button>
</div>
